@@ -103,6 +103,9 @@ class Lamp:
     def route(self, route: str, domain: Union[str, bool] = None, method: list = []):
         def inner(func):
             
+            if domain:
+                domain = str(domain)
+
             key = json.dumps({'route': str(route), 'domain': domain, 'method': method})
 
             self.routes[key] = func
